<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="de">
<context>
    <name>BottomBar</name>
    <message>
        <location filename="../src/widgets/bottombar.cpp" line="39"/>
        <source>Row</source>
        <translation>Zeile</translation>
    </message>
    <message>
        <location filename="../src/widgets/bottombar.cpp" line="40"/>
        <source>Column</source>
        <translation>Spalte</translation>
    </message>
    <message>
        <location filename="../src/widgets/bottombar.cpp" line="41"/>
        <source>Characters %1</source>
        <translation>Zeichen %1</translation>
    </message>
</context>
<context>
    <name>DDropdownMenu</name>
    <message>
        <location filename="../src/widgets/ddropdownmenu.cpp" line="300"/>
        <location filename="../src/widgets/ddropdownmenu.cpp" line="344"/>
        <location filename="../src/widgets/ddropdownmenu.cpp" line="349"/>
        <source>None</source>
        <translation>Keines</translation>
    </message>
</context>
<context>
    <name>EditWrapper</name>
    <message>
        <location filename="../src/editor/editwrapper.cpp" line="201"/>
        <location filename="../src/editor/editwrapper.cpp" line="264"/>
        <location filename="../src/editor/editwrapper.cpp" line="321"/>
        <location filename="../src/editor/editwrapper.cpp" line="536"/>
        <source>Save</source>
        <translation>Speichern</translation>
    </message>
    <message>
        <location filename="../src/editor/editwrapper.cpp" line="316"/>
        <source>Do you want to save this file?</source>
        <translation>Möchten Sie diese Datei speichern?</translation>
    </message>
    <message>
        <location filename="../src/editor/editwrapper.cpp" line="262"/>
        <location filename="../src/editor/editwrapper.cpp" line="319"/>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <location filename="../src/editor/editwrapper.cpp" line="259"/>
        <source>Encoding changed. Do you want to save the file now?</source>
        <translation>Kodierung geändert. Wollen Sie die Datei jetzt speichern?</translation>
    </message>
    <message>
        <location filename="../src/editor/editwrapper.cpp" line="320"/>
        <source>Discard</source>
        <translation>Verwerfen</translation>
    </message>
    <message>
        <location filename="../src/editor/editwrapper.cpp" line="445"/>
        <source>You do not have permission to save %1</source>
        <translation>Berechtigung zum Speichern von %1 fehlt</translation>
    </message>
    <message>
        <location filename="../src/editor/editwrapper.cpp" line="607"/>
        <source>File removed on the disk. Save it now?</source>
        <translation>Die Datei wurde von der Festplatte entfernt. Soll die Datei jetzt gespeichert werden. </translation>
    </message>
    <message>
        <location filename="../src/editor/editwrapper.cpp" line="612"/>
        <source>File has changed on disk. Reload?</source>
        <translation>Die Datei wurde verändert.. Soll die Datei neu geladen werden?</translation>
    </message>
    <message>
        <location filename="../src/editor/editwrapper.cpp" line="634"/>
        <location filename="../src/widgets/bottombar.cpp" line="60"/>
        <source>INSERT</source>
        <translation>EINFÜGEN</translation>
    </message>
    <message>
        <location filename="../src/editor/editwrapper.cpp" line="637"/>
        <source>OVERWRITE</source>
        <translation>ÜBERSCHREIBEN</translation>
    </message>
    <message>
        <location filename="../src/editor/editwrapper.cpp" line="640"/>
        <source>R/O</source>
        <translation>R/O</translation>
    </message>
</context>
<context>
    <name>FindBar</name>
    <message>
        <location filename="../src/controls/findbar.cpp" line="40"/>
        <source>Find</source>
        <translation>Suchen</translation>
    </message>
    <message>
        <location filename="../src/controls/findbar.cpp" line="44"/>
        <source>Previous</source>
        <translation>Vorheriges</translation>
    </message>
    <message>
        <location filename="../src/controls/findbar.cpp" line="46"/>
        <source>Next</source>
        <translation>Nächstes</translation>
    </message>
</context>
<context>
    <name>JumpLineBar</name>
    <message>
        <location filename="../src/controls/jumplinebar.cpp" line="40"/>
        <source>Go to Line: </source>
        <translation>Gehe zu Zeile:</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/editorapplication.cpp" line="27"/>
        <source>Text Editor is a powerful tool for viewing and editing text files.</source>
        <translation>Der Texteditor ist ein leistungsstarkes Tool zum Anzeigen und Bearbeiten von Textdateien.</translation>
    </message>
    <message>
        <location filename="../src/editorapplication.cpp" line="38"/>
        <source>Text Editor</source>
        <translation>Texteditor</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/editorapplication.cpp" line="35"/>
        <source>Text Editor</source>
        <translation>Texteditor</translation>
    </message>
    <message>
        <location filename="../src/editor/editwrapper.cpp" line="203"/>
        <location filename="../src/editor/editwrapper.cpp" line="538"/>
        <location filename="../src/widgets/window.cpp" line="956"/>
        <location filename="../src/widgets/window.cpp" line="973"/>
        <location filename="../src/widgets/window.cpp" line="1064"/>
        <location filename="../src/widgets/window.cpp" line="1079"/>
        <source>Encoding</source>
        <translation>Kodierung</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="24"/>
        <source>Basic</source>
        <translation>Basis</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="25"/>
        <source>Font Style</source>
        <translation>Schriftstil</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="26"/>
        <source>Font</source>
        <translation>Schriftart</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="27"/>
        <source>Font Size</source>
        <translation>Schriftgröße</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="28"/>
        <source>Shortcuts</source>
        <translation>Tastaturkürzel</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="29"/>
        <location filename="../src/controls/settingsdialog.cpp" line="30"/>
        <source>Keymap</source>
        <translation>Tastaturbelegung</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="31"/>
        <location filename="../src/controls/settingsdialog.cpp" line="107"/>
        <location filename="../src/widgets/window.cpp" line="1482"/>
        <source>Window</source>
        <translation>Fenster</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="32"/>
        <source>New tab</source>
        <translation>Neuer Tab</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="33"/>
        <source>New window</source>
        <translation>Neues Fenster</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="34"/>
        <source>Save</source>
        <translation>Speichern</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="35"/>
        <source>Save as</source>
        <translation>Speichern unter</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="36"/>
        <source>Next tab</source>
        <translation>Nächster Tab</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="37"/>
        <source>Previous tab</source>
        <translation>Vorheriger Tab</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="38"/>
        <source>Close tab</source>
        <translation>Tab schließen</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="39"/>
        <source>Close other tabs</source>
        <translation>Andere Tabs schließen</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="40"/>
        <source>Restore tab</source>
        <translation>Tab wiederherstellen</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="41"/>
        <source>Open file</source>
        <translation>Datei öffnen</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="42"/>
        <source>Increment font size</source>
        <translation>Schriftgröße erhöhen</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="43"/>
        <source>Decrement font size</source>
        <translation>Schriftgröße verringern</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="44"/>
        <source>Reset font size</source>
        <translation>Schriftgröße zurücksetzen</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="45"/>
        <source>Help</source>
        <translation>Hilfe</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="46"/>
        <source>Toggle fullscreen</source>
        <translation>Vollbildmodus umschalten</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="47"/>
        <source>Find</source>
        <translation>Suchen</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="48"/>
        <source>Replace</source>
        <translation>Ersetzen</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="49"/>
        <source>Go to line</source>
        <translation>Gehe zu Zeile</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="50"/>
        <source>Save cursor position</source>
        <translation>Position des Schreibmarkers speichern</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="51"/>
        <source>Reset cursor position</source>
        <translation>Position des Schreibmarkers zurücksetzen</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="52"/>
        <source>Exit</source>
        <translation>Beenden</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="53"/>
        <source>Display shortcuts</source>
        <translation>Tastaturkürzel anzeigen</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="54"/>
        <source>Print</source>
        <translation>Drucken</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="55"/>
        <source>Editor</source>
        <translation>Editor</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="56"/>
        <source>Increase indent</source>
        <translation>Einrückung vergrößern</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="57"/>
        <source>Decrease indent</source>
        <translation>Einrückung verringern</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="58"/>
        <source>Forward character</source>
        <translation>Ein Zeichen vorwärts</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="59"/>
        <source>Backward character</source>
        <translation>Ein Zeichen rückwärts</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="60"/>
        <source>Forward word</source>
        <translation>Ein Wort vorwärts</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="61"/>
        <source>Backward word</source>
        <translation>Ein Wort rückwärts</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="62"/>
        <source>Next line</source>
        <translation>Nächste Zeile</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="63"/>
        <source>Previous line</source>
        <translation>Vorherige Zeile</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="64"/>
        <source>New line</source>
        <translation>Neue Zeile</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="65"/>
        <source>New line above</source>
        <translation>Neue Zeile davor</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="66"/>
        <source>New line below</source>
        <translation>Neue Zeile danach</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="67"/>
        <source>Duplicate line</source>
        <translation>Zeile duplizieren</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="68"/>
        <source>Delete to end of line</source>
        <translation>Ende der Zeile löschen</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="69"/>
        <source>Delete current line</source>
        <translation>Aktuelle Zeile entfernen</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="70"/>
        <source>Swap line up</source>
        <translation>Zeile nach oben verschieben</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="71"/>
        <source>Swap line down</source>
        <translation>Zeile nach unten verschieben</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="72"/>
        <source>Scroll up one line</source>
        <translation>Eine Zeile hoch</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="73"/>
        <source>Scroll down one line</source>
        <translation>Eine Zeile runter</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="74"/>
        <source>Page up</source>
        <translation>Eine Seite nach oben</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="75"/>
        <source>Page down</source>
        <translation>Eine Seite nach unten</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="76"/>
        <source>Move to end of line</source>
        <translation>Zum Ende der Zeile bewegen</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="77"/>
        <source>Move to start of line</source>
        <translation>Zum Anfang der Zeile bewegen</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="78"/>
        <source>Move to end of text</source>
        <translation>Zum Ende des Texts bewegen</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="79"/>
        <source>Move to start of text</source>
        <translation>Zum Anfang des Texts bewegen</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="80"/>
        <source>Move to line indentation</source>
        <translation>Zur Zeileneinrückung bewegen</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="81"/>
        <source>Upper case</source>
        <translation>Großbuchstaben</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="82"/>
        <source>Lower case</source>
        <translation>Kleinbuchstaben</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="83"/>
        <source>Capitalize</source>
        <translation>Großschreibung</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="84"/>
        <source>Delete backward word</source>
        <translation>Ein Wort rückwärts entfernen</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="85"/>
        <source>Delete forward word</source>
        <translation>Ein Wort vorwärts entfernen</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="86"/>
        <source>Forward over a pair</source>
        <translation>Vorwärts über ein Paar</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="87"/>
        <source>Backward over a pair</source>
        <translation>Rückwärts über ein Paar</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="88"/>
        <source>Select all</source>
        <translation>Alles markieren</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="89"/>
        <source>Copy</source>
        <translation>Kopieren</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="90"/>
        <source>Cut</source>
        <translation>Ausschneiden</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="91"/>
        <source>Paste</source>
        <translation>Einfügen</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="92"/>
        <source>Transpose character</source>
        <translation>Zeichen transponieren</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="93"/>
        <source>Mark</source>
        <translation>Markieren</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="94"/>
        <source>Unmark</source>
        <translation>Markierung aufheben</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="95"/>
        <source>Copy line</source>
        <translation>Zeile kopieren</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="96"/>
        <source>Cut line</source>
        <translation>Zeile ausschneiden</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="97"/>
        <source>Merge lines</source>
        <translation>Zeilen zusammenfügen</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="98"/>
        <source>Read-Only mode</source>
        <translation>Nur-Lese-Modus</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="99"/>
        <source>Add comment</source>
        <translation>Kommentar hinzufügen</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="100"/>
        <source>Remove comment</source>
        <translation>Kommentar entfernen</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="101"/>
        <source>Undo</source>
        <translation>Rückgängig</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="102"/>
        <source>Redo</source>
        <translation>Wiederherstellen</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="103"/>
        <source>Add/Remove bookmark</source>
        <translation>Lesezeichen hinzufügen/entfernen</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="104"/>
        <source>Move to previous bookmark</source>
        <translation>Zum vorherigen Lesezeichen wechseln</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="105"/>
        <source>Move to next bookmark</source>
        <translation>Zum nächsten Lesezeichen wechseln</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="106"/>
        <source>Advanced</source>
        <translation>Erweitert</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="108"/>
        <source>Window size</source>
        <translation>Fenstergröße</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="109"/>
        <source>Tab width</source>
        <translation>Tabulatorbreite</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="111"/>
        <source>Word wrap</source>
        <translation>Zeilenumbruch</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="112"/>
        <source>Code folding flag</source>
        <translation>Code-Einklapp-Schalter</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="113"/>
        <source>Show line numbers</source>
        <translation>Zeilennummern anzeigen</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="114"/>
        <source>Show bookmarks icon</source>
        <translation>Lesezeichensymbol anzeigen</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="115"/>
        <source>Show whitespaces and tabs</source>
        <translation>Leerzeichen und Tabulatoren anzeigen</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="116"/>
        <source>Highlight current line</source>
        <translation>Aktuelle Zeile markieren</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="117"/>
        <source>Color mark</source>
        <translation>Farbmarkierung</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="120"/>
        <source>Unicode</source>
        <translation>Unicode</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="121"/>
        <source>WesternEuropean</source>
        <translation>Westeuropäisch</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="122"/>
        <source>CentralEuropean</source>
        <translation>Mitteleuropäisch</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="123"/>
        <source>Baltic</source>
        <translation>Baltisch</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="124"/>
        <source>Cyrillic</source>
        <translation>Kyrillisch</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="125"/>
        <source>Arabic</source>
        <translation>Arabisch</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="130"/>
        <source>Celtic</source>
        <translation>Keltisch</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="131"/>
        <source>SouthEasternEuropean</source>
        <translation>Südosteuropäisch</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="126"/>
        <source>Greek</source>
        <translation>Griechisch</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="127"/>
        <source>Hebrew</source>
        <translation>Hebräisch</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="132"/>
        <source>ChineseSimplified</source>
        <translation>ChinesischVereinfacht</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="133"/>
        <source>ChineseTraditional</source>
        <translation>ChinesischTraditionell</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="134"/>
        <source>Japanese</source>
        <translation>Japanisch</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="135"/>
        <source>Korean</source>
        <translation>Koreanisch</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="129"/>
        <source>Thai</source>
        <translation>Thailändisch</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="128"/>
        <source>Turkish</source>
        <translation>Türkisch</translation>
    </message>
    <message>
        <location filename="../src/controls/settingsdialog.cpp" line="136"/>
        <source>Vietnamese</source>
        <translation>Vietnamesisch</translation>
    </message>
    <message>
        <location filename="../src/startmanager.cpp" line="762"/>
        <source>File not saved</source>
        <translation>Datei nicht gespeichert</translation>
    </message>
    <message>
        <location filename="../src/widgets/window.cpp" line="974"/>
        <location filename="../src/widgets/window.cpp" line="1065"/>
        <location filename="../src/widgets/window.cpp" line="1080"/>
        <source>Line Endings</source>
        <translation>Zeilenenden</translation>
    </message>
</context>
<context>
    <name>ReplaceBar</name>
    <message>
        <location filename="../src/controls/replacebar.cpp" line="39"/>
        <source>Find</source>
        <translation>Suchen</translation>
    </message>
    <message>
        <location filename="../src/controls/replacebar.cpp" line="43"/>
        <source>Replace With</source>
        <translation>Ersetzen mit</translation>
    </message>
    <message>
        <location filename="../src/controls/replacebar.cpp" line="47"/>
        <source>Replace</source>
        <translation>Ersetzen</translation>
    </message>
    <message>
        <location filename="../src/controls/replacebar.cpp" line="50"/>
        <source>Skip</source>
        <translation>Überspringen</translation>
    </message>
    <message>
        <location filename="../src/controls/replacebar.cpp" line="53"/>
        <source>Replace Rest</source>
        <translation>Rest ersetzen</translation>
    </message>
    <message>
        <location filename="../src/controls/replacebar.cpp" line="56"/>
        <source>Replace All</source>
        <translation>Alles ersetzen</translation>
    </message>
</context>
<context>
    <name>S:</name>
    <message>
        <location filename="../third/libiconv-1.16/src/iconv.c" line="103"/>
        <source/>
        <comment>The first line of the short usage message.</comment>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Settings</name>
    <message>
        <location filename="../src/common/settings.cpp" line="91"/>
        <source>Standard</source>
        <translation>Standard</translation>
    </message>
    <message>
        <location filename="../src/common/settings.cpp" line="91"/>
        <source>Customize</source>
        <translation>Anpassen</translation>
    </message>
    <message>
        <location filename="../src/common/settings.cpp" line="104"/>
        <source>Normal</source>
        <translation>Normal</translation>
    </message>
    <message>
        <location filename="../src/common/settings.cpp" line="104"/>
        <source>Maximum</source>
        <translation>Maximum</translation>
    </message>
    <message>
        <location filename="../src/common/settings.cpp" line="104"/>
        <source>Fullscreen</source>
        <translation>Vollbild</translation>
    </message>
    <message>
        <location filename="../src/common/settings.cpp" line="292"/>
        <source>This shortcut conflicts with system shortcut %1</source>
        <translation>Dieses Tastaturkürzel steht im Konflikt mit dem Systemkürzel %1</translation>
    </message>
    <message>
        <location filename="../src/common/settings.cpp" line="294"/>
        <source>This shortcut conflicts with %1, click on Replace to make this shortcut effective immediately</source>
        <translation>Dieses Tastaturkürzel steht im Konflikt mit %1, klicke auf Ersetzen, um dieses Kürzel sofort wirksam zu machen</translation>
    </message>
    <message>
        <location filename="../src/common/settings.cpp" line="410"/>
        <location filename="../src/common/settings.cpp" line="418"/>
        <source>The shortcut %1 is invalid, please set another one.</source>
        <translation>Das Tastaturkürzel %1 ist ungültig, bitte stelle ein anderes ein.</translation>
    </message>
    <message>
        <location filename="../src/common/settings.cpp" line="445"/>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <location filename="../src/common/settings.cpp" line="446"/>
        <source>Replace</source>
        <translation>Ersetzen</translation>
    </message>
    <message>
        <location filename="../src/common/settings.cpp" line="448"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>StartManager</name>
    <message>
        <location filename="../src/startmanager.cpp" line="340"/>
        <source>Untitled %1</source>
        <translation>Unbenannt %1</translation>
    </message>
</context>
<context>
    <name>Tabbar</name>
    <message>
        <location filename="../src/controls/tabbar.cpp" line="515"/>
        <source>Close tab</source>
        <translation>Tab schließen</translation>
    </message>
    <message>
        <location filename="../src/controls/tabbar.cpp" line="516"/>
        <source>Close other tabs</source>
        <translation>Schließe restliche Tabs</translation>
    </message>
    <message>
        <location filename="../src/controls/tabbar.cpp" line="517"/>
        <source>More options</source>
        <translation>Weitere Optionen</translation>
    </message>
    <message>
        <location filename="../src/controls/tabbar.cpp" line="518"/>
        <source>Close tabs to the left</source>
        <translation>Tabs nach links schließen</translation>
    </message>
    <message>
        <location filename="../src/controls/tabbar.cpp" line="519"/>
        <source>Close tabs to the right</source>
        <translation>Tabs nach rechts schließen</translation>
    </message>
    <message>
        <location filename="../src/controls/tabbar.cpp" line="520"/>
        <source>Close unmodified tabs</source>
        <translation>Unveränderte Tabs schließen</translation>
    </message>
</context>
<context>
    <name>TextEdit</name>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="235"/>
        <source>Undo</source>
        <translation>Rückgängig</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="236"/>
        <source>Redo</source>
        <translation>Wiederherstellen</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="237"/>
        <source>Cut</source>
        <translation>Ausschneiden</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="238"/>
        <source>Copy</source>
        <translation>Kopieren</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="239"/>
        <source>Paste</source>
        <translation>Einfügen</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="240"/>
        <source>Delete</source>
        <translation>Löschen</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="241"/>
        <source>Select All</source>
        <translation>Alles auswählen</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="242"/>
        <location filename="../src/widgets/window.cpp" line="361"/>
        <source>Find</source>
        <translation>Suchen</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="243"/>
        <location filename="../src/widgets/window.cpp" line="362"/>
        <source>Replace</source>
        <translation>Ersetzen</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="244"/>
        <source>Go to Line</source>
        <translation>Gehe zu Zeile</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="245"/>
        <source>Turn on Read-Only mode</source>
        <translation>Nur-Lese-Modus aktivieren</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="246"/>
        <source>Turn off Read-Only mode</source>
        <translation>Nur-Lese-Modus deaktivieren</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="247"/>
        <source>Fullscreen</source>
        <translation>Vollbild</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="248"/>
        <source>Exit fullscreen</source>
        <translation>Vollbild beenden</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="249"/>
        <source>Display in file manager</source>
        <translation>Im Dateimanager anzeigen</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="250"/>
        <location filename="../src/editor/dtextedit.cpp" line="302"/>
        <source>Add Comment</source>
        <translation>Kommentar hinzufügen</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="251"/>
        <source>Text to Speech</source>
        <translation>Text zu Sprache</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="252"/>
        <source>Stop reading</source>
        <translation>Lesen beenden</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="253"/>
        <source>Speech to Text</source>
        <translation>Sprache zu Text</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="254"/>
        <source>Translate</source>
        <translation>Übersetzen</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="255"/>
        <source>Column Mode</source>
        <translation>Spaltenmodus</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="256"/>
        <source>Add bookmark</source>
        <translation>Lesezeichen hinzufügen</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="257"/>
        <source>Remove Bookmark</source>
        <translation>Lesezeichen entfernen</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="258"/>
        <source>Previous bookmark</source>
        <translation>Vorheriges Lesezeichen</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="259"/>
        <source>Next bookmark</source>
        <translation>Nächstes Lesezeichen</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="260"/>
        <source>Remove All Bookmarks</source>
        <translation>Alle Lesezeichen entfernen</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="261"/>
        <source>Fold All</source>
        <translation>Alles einfalten</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="262"/>
        <source>Fold Current Level</source>
        <translation>Aktuelle Ebene einfalten</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="263"/>
        <source>Unfold All</source>
        <translation>Alles ausfalten</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="264"/>
        <source>Unfold Current Level</source>
        <translation>Aktuelle Ebene ausfalten</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="269"/>
        <source>Color Mark</source>
        <translation>Farbmarkierung</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="273"/>
        <source>Clear All Marks</source>
        <translation>Alle Markierungen löschen</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="274"/>
        <source>Clear Last Mark</source>
        <translation>Letzte Markierung löschen</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="283"/>
        <source>Mark</source>
        <translation>Markieren</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="295"/>
        <source>Mark All</source>
        <translation>Alles markieren</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="303"/>
        <source>Remove Comment</source>
        <translation>Kommentar entfernen</translation>
    </message>
    <message>
        <source>Failed to paste text: it is too large</source>
        <translation type="vanished">Der Text konnte nicht eingefügt werden, da er zu lang ist</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="2581"/>
        <source>Copy failed: not enough memory</source>
        <translation>Kopieren fehlgeschlagen: nicht genügend Speicher</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="2665"/>
        <source>Press ALT and click lines to edit in column mode</source>
        <translation>Drücke ALT und klicke auf Zeilen, um im Spaltenmodus zu bearbeiten</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="346"/>
        <source>Change Case</source>
        <translation>Groß-/Kleinschreibung ändern</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="347"/>
        <source>Upper Case</source>
        <translation>Großbuchstaben</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="348"/>
        <source>Lower Case</source>
        <translation>Kleinbuchstaben</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="349"/>
        <source>Capitalize</source>
        <translation>Großschreibung</translation>
    </message>
    <message>
        <location filename="../src/widgets/bottombar.cpp" line="64"/>
        <source>None</source>
        <translation>Keines</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="1184"/>
        <source>Selected line(s) copied</source>
        <translation>Ausgewählte Zeile(n) kopiert</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="1190"/>
        <source>Current line copied</source>
        <translation>Aktuelle Zeile kopiert</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="1210"/>
        <source>Selected line(s) clipped</source>
        <translation>Ausgewählte Zeile(n) abgeschnitten</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="1222"/>
        <source>Current line clipped</source>
        <translation>Aktuelle Zeile abgeschnitten</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="2591"/>
        <source>Paste failed: not enough memory</source>
        <translation>Einfügen fehlgeschlagen: nicht genügend Speicher</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="3439"/>
        <source>Read-Only mode is off</source>
        <translation>Nur-Lese-Modus ist ausgeschaltet</translation>
    </message>
    <message>
        <location filename="../src/editor/dtextedit.cpp" line="3446"/>
        <location filename="../src/editor/dtextedit.cpp" line="3465"/>
        <location filename="../src/editor/dtextedit.cpp" line="6150"/>
        <source>Read-Only mode is on</source>
        <translation>Nur-Lese-Modus ist eingeschaltet</translation>
    </message>
</context>
<context>
    <name>WarningNotices</name>
    <message>
        <location filename="../src/controls/warningnotices.cpp" line="36"/>
        <source>Reload</source>
        <translation>Neu laden</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <location filename="../src/controls/warningnotices.cpp" line="38"/>
        <location filename="../src/widgets/window.cpp" line="357"/>
        <source>Save as</source>
        <translation>Speichern unter</translation>
    </message>
    <message>
        <location filename="../src/widgets/window.cpp" line="353"/>
        <source>New window</source>
        <translation>Neues Fenster</translation>
    </message>
    <message>
        <location filename="../src/widgets/window.cpp" line="354"/>
        <source>New tab</source>
        <translation>Neuer Tab</translation>
    </message>
    <message>
        <location filename="../src/widgets/window.cpp" line="355"/>
        <source>Open file</source>
        <translation>Datei öffnen</translation>
    </message>
    <message>
        <location filename="../src/widgets/window.cpp" line="356"/>
        <location filename="../src/widgets/window.cpp" line="2217"/>
        <source>Save</source>
        <translation>Speichern</translation>
    </message>
    <message>
        <location filename="../src/widgets/window.cpp" line="358"/>
        <source>Print</source>
        <translation>Drucken</translation>
    </message>
    <message>
        <location filename="../src/widgets/window.cpp" line="359"/>
        <source>Switch theme</source>
        <translation>Theme wechseln</translation>
    </message>
    <message>
        <location filename="../src/widgets/window.cpp" line="360"/>
        <location filename="../src/widgets/window.cpp" line="1542"/>
        <source>Settings</source>
        <translation>Einstellungen</translation>
    </message>
    <message>
        <location filename="../src/widgets/window.cpp" line="471"/>
        <location filename="../src/widgets/window.cpp" line="2468"/>
        <source>Read-Only</source>
        <translation>Nur Lesen</translation>
    </message>
    <message>
        <location filename="../src/widgets/window.cpp" line="487"/>
        <source>You do not have permission to open %1</source>
        <translation>Berechtigung zum Öffnen von %1 fehlt</translation>
    </message>
    <message>
        <location filename="../src/widgets/window.cpp" line="522"/>
        <source>Invalid file: %1</source>
        <translation>Ungültige Datei: %1</translation>
    </message>
    <message>
        <location filename="../src/widgets/window.cpp" line="602"/>
        <location filename="../src/widgets/window.cpp" line="644"/>
        <source>Do you want to save this file?</source>
        <translation>Möchten Sie diese Datei speichern?</translation>
    </message>
    <message>
        <location filename="../src/widgets/window.cpp" line="894"/>
        <source>You do not have permission to save %1</source>
        <translation>Berechtigung zum Speichern von %1 fehlt</translation>
    </message>
    <message>
        <location filename="../src/widgets/window.cpp" line="918"/>
        <source>Saved successfully</source>
        <translation>Erfolgreich gespeichert</translation>
    </message>
    <message>
        <location filename="../src/widgets/window.cpp" line="954"/>
        <location filename="../src/widgets/window.cpp" line="1021"/>
        <location filename="../src/widgets/window.cpp" line="1062"/>
        <source>Save File</source>
        <translation>Datei speichern</translation>
    </message>
    <message>
        <location filename="../src/widgets/window.cpp" line="1023"/>
        <source>Encoding</source>
        <translation>Kodierung</translation>
    </message>
    <message>
        <location filename="../src/widgets/window.cpp" line="1211"/>
        <source>Read-Only mode is on</source>
        <translation>Nur-Lese-Modus ist aktiviert</translation>
    </message>
    <message>
        <location filename="../src/widgets/window.cpp" line="1441"/>
        <source>Current location remembered</source>
        <translation>Aktueller Standort gespeichert</translation>
    </message>
    <message>
        <location filename="../src/widgets/window.cpp" line="1492"/>
        <source>Ctrl+&apos;=&apos;</source>
        <translation>Strg+&apos;=&apos;</translation>
    </message>
    <message>
        <location filename="../src/widgets/window.cpp" line="1495"/>
        <source>Ctrl+&apos;-&apos;</source>
        <translation>Strg+&apos;-&apos;</translation>
    </message>
    <message>
        <location filename="../src/widgets/window.cpp" line="1524"/>
        <source>Editor</source>
        <translation>Editor</translation>
    </message>
    <message>
        <location filename="../src/widgets/window.cpp" line="1890"/>
        <source>Untitled %1</source>
        <translation>Unbenannt %1</translation>
    </message>
    <message>
        <location filename="../src/widgets/window.cpp" line="2215"/>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <location filename="../src/widgets/window.cpp" line="2216"/>
        <source>Discard</source>
        <translation>Verwerfen</translation>
    </message>
</context>
</TS>